# toolkit4life
A PyPI package to help speed-up development and make life easier.

## Features
- **logger**: Different decorators to use on your fuctions
- **threads**: *Thread* and *ThreadPool* with return values
- **requests**: Send requests with Backoff-Strategy
- **clients**:
  - **redis**: Redis-Client
  - **trino**: trino-Client
  - **postgre**: PostgreSQL-Client
